==> ec2-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnVPCEndpointServiceProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::VPCEndpointService`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservice.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:23:14.044Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnVPCEndpointServiceProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::EC2::VPCEndpointService.NetworkLoadBalancerArns`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservice.html#cfn-ec2-vpcendpointservice-networkloadbalancerarns
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getNetworkLoadBalancerArns();

    /**
     * `AWS::EC2::VPCEndpointService.AcceptanceRequired`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservice.html#cfn-ec2-vpcendpointservice-acceptancerequired
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getAcceptanceRequired();

    /**
     * @return a {@link Builder} of {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.util.List<java.lang.String> networkLoadBalancerArns;
        private java.lang.Object acceptanceRequired;

        /**
         * Sets the value of NetworkLoadBalancerArns
         * @param networkLoadBalancerArns `AWS::EC2::VPCEndpointService.NetworkLoadBalancerArns`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder networkLoadBalancerArns(java.util.List<java.lang.String> networkLoadBalancerArns) {
            this.networkLoadBalancerArns = networkLoadBalancerArns;
            return this;
        }

        /**
         * Sets the value of AcceptanceRequired
         * @param acceptanceRequired `AWS::EC2::VPCEndpointService.AcceptanceRequired`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder acceptanceRequired(java.lang.Boolean acceptanceRequired) {
            this.acceptanceRequired = acceptanceRequired;
            return this;
        }

        /**
         * Sets the value of AcceptanceRequired
         * @param acceptanceRequired `AWS::EC2::VPCEndpointService.AcceptanceRequired`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder acceptanceRequired(software.amazon.awscdk.core.IResolvable acceptanceRequired) {
            this.acceptanceRequired = acceptanceRequired;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVPCEndpointServiceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnVPCEndpointServiceProps build() {
            return new Jsii$Proxy(networkLoadBalancerArns, acceptanceRequired);
        }
    }

    /**
     * An implementation for {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnVPCEndpointServiceProps {
        private final java.util.List<java.lang.String> networkLoadBalancerArns;
        private final java.lang.Object acceptanceRequired;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.networkLoadBalancerArns = this.jsiiGet("networkLoadBalancerArns", java.util.List.class);
            this.acceptanceRequired = this.jsiiGet("acceptanceRequired", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.util.List<java.lang.String> networkLoadBalancerArns, java.lang.Object acceptanceRequired) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.networkLoadBalancerArns = java.util.Objects.requireNonNull(networkLoadBalancerArns, "networkLoadBalancerArns is required");
            this.acceptanceRequired = acceptanceRequired;
        }

        @Override
        public java.util.List<java.lang.String> getNetworkLoadBalancerArns() {
            return this.networkLoadBalancerArns;
        }

        @Override
        public java.lang.Object getAcceptanceRequired() {
            return this.acceptanceRequired;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("networkLoadBalancerArns", om.valueToTree(this.getNetworkLoadBalancerArns()));
            if (this.getAcceptanceRequired() != null) {
                obj.set("acceptanceRequired", om.valueToTree(this.getAcceptanceRequired()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnVPCEndpointServiceProps.Jsii$Proxy that = (CfnVPCEndpointServiceProps.Jsii$Proxy) o;

            if (!networkLoadBalancerArns.equals(that.networkLoadBalancerArns)) return false;
            return this.acceptanceRequired != null ? this.acceptanceRequired.equals(that.acceptanceRequired) : that.acceptanceRequired == null;
        }

        @Override
        public int hashCode() {
            int result = this.networkLoadBalancerArns.hashCode();
            result = 31 * result + (this.acceptanceRequired != null ? this.acceptanceRequired.hashCode() : 0);
            return result;
        }
    }
}

==> ec2-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnVPCEndpointServiceProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::VPCEndpointService`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservice.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:50.795Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.CfnVPCEndpointServiceProps")
@software.amazon.jsii.Jsii.Proxy(CfnVPCEndpointServiceProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnVPCEndpointServiceProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::EC2::VPCEndpointService.NetworkLoadBalancerArns`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservice.html#cfn-ec2-vpcendpointservice-networkloadbalancerarns
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getNetworkLoadBalancerArns();

    /**
     * `AWS::EC2::VPCEndpointService.AcceptanceRequired`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpcendpointservice.html#cfn-ec2-vpcendpointservice-acceptancerequired
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.Object getAcceptanceRequired() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.util.List<java.lang.String> networkLoadBalancerArns;
        private java.lang.Object acceptanceRequired;

        /**
         * Sets the value of NetworkLoadBalancerArns
         * @param networkLoadBalancerArns `AWS::EC2::VPCEndpointService.NetworkLoadBalancerArns`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder networkLoadBalancerArns(java.util.List<java.lang.String> networkLoadBalancerArns) {
            this.networkLoadBalancerArns = networkLoadBalancerArns;
            return this;
        }

        /**
         * Sets the value of AcceptanceRequired
         * @param acceptanceRequired `AWS::EC2::VPCEndpointService.AcceptanceRequired`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder acceptanceRequired(java.lang.Boolean acceptanceRequired) {
            this.acceptanceRequired = acceptanceRequired;
            return this;
        }

        /**
         * Sets the value of AcceptanceRequired
         * @param acceptanceRequired `AWS::EC2::VPCEndpointService.AcceptanceRequired`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder acceptanceRequired(software.amazon.awscdk.core.IResolvable acceptanceRequired) {
            this.acceptanceRequired = acceptanceRequired;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVPCEndpointServiceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnVPCEndpointServiceProps build() {
            return new Jsii$Proxy(networkLoadBalancerArns, acceptanceRequired);
        }
    }

    /**
     * An implementation for {@link CfnVPCEndpointServiceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnVPCEndpointServiceProps {
        private final java.util.List<java.lang.String> networkLoadBalancerArns;
        private final java.lang.Object acceptanceRequired;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.networkLoadBalancerArns = this.jsiiGet("networkLoadBalancerArns", java.util.List.class);
            this.acceptanceRequired = this.jsiiGet("acceptanceRequired", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.util.List<java.lang.String> networkLoadBalancerArns, final java.lang.Object acceptanceRequired) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.networkLoadBalancerArns = java.util.Objects.requireNonNull(networkLoadBalancerArns, "networkLoadBalancerArns is required");
            this.acceptanceRequired = acceptanceRequired;
        }

        @Override
        public java.util.List<java.lang.String> getNetworkLoadBalancerArns() {
            return this.networkLoadBalancerArns;
        }

        @Override
        public java.lang.Object getAcceptanceRequired() {
            return this.acceptanceRequired;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("networkLoadBalancerArns", om.valueToTree(this.getNetworkLoadBalancerArns()));
            if (this.getAcceptanceRequired() != null) {
                data.set("acceptanceRequired", om.valueToTree(this.getAcceptanceRequired()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ec2.CfnVPCEndpointServiceProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnVPCEndpointServiceProps.Jsii$Proxy that = (CfnVPCEndpointServiceProps.Jsii$Proxy) o;

            if (!networkLoadBalancerArns.equals(that.networkLoadBalancerArns)) return false;
            return this.acceptanceRequired != null ? this.acceptanceRequired.equals(that.acceptanceRequired) : that.acceptanceRequired == null;
        }

        @Override
        public int hashCode() {
            int result = this.networkLoadBalancerArns.hashCode();
            result = 31 * result + (this.acceptanceRequired != null ? this.acceptanceRequired.hashCode() : 0);
            return result;
        }
    }
}
